import React from 'react'
import { Layout, Loading, Main } from './components'
import { withRouter } from 'react-router-dom'
import socket from './socket'

const initialState = { loading: true, blocks: [], timestamp: 0 }

class App extends React.Component {
  initializeSocket() {
    socket.on('connect', () => {
      if (!socket.id) console.log('no websocket connection')
      else console.log('my socketId:', socket.id)
    })
    socket.on('block', (block) => {
      const blocks = this.state.blocks
        .filter((b) => b.id !== block.id)
        .concat(block)
        .sort((a, b) => b.id - a.id)
      this.setState({ loading: false, blocks, timestamp: block.timestamp })
    })
  }

  renderError() {
    if (this.state.showModal === 'Error') return
    this.setShowModal('Error')
  }
  renderApp() {
    return <Main {...this.state} />
  }
  render() {
    if (this.state.loading) return <Loading />
    if (this.state.error) this.renderError()
    if (this.state.component === 'layout') return <Layout {...this.state} />
    return this.renderApp()
  }

  componentDidMount() {
    this.initializeSocket()
    setInterval(() => this.setState({}), 100)
  }
  componentWillUnmount() {
    console.log('unmounting...')
  }
  constructor() {
    super()
    this.state = initialState
  }
}

export default withRouter(App)
