import React from 'react'
import moment from 'moment'
import { CSSTransition, TransitionGroup } from 'react-transition-group'

const Main = (props) => {
  const { blocks, timestamp } = props
  const timePassed = moment().diff(timestamp) / 1000

  return (
    <div className="w-100 h-100 d-flex flex-column overflow-hidden">
      <div className="h-100 flex-grow-1 d-flex flex-row justify-content-between">
        <div className="col-4 p-3 text-light" style={{ background: '#000' }}>
          <div className="float-right mt-3">
            <b>{timePassed.toFixed(1)} s</b>
          </div>
          <h3>recent blocks</h3>
          <TransitionGroup>
            {blocks.map(({ id, author, blocktime, timestamp }) => (
              <CSSTransition
                in={true}
                classNames="block"
                timeout={100}
                key={id}
                appear
              >
                <div
                  key={id}
                  className="block text-center text-dark bg-light m-2 p-2"
                >
                  <div className="float-left">
                    <b>{id}</b>
                  </div>
                  <div className="float-right">
                    {moment(timestamp).format('HH:mm:ss')}
                  </div>
                  {(blocktime / 1000).toFixed(3)} s
                  <div>
                    <small>{author}</small>
                  </div>
                </div>
              </CSSTransition>
            ))}
          </TransitionGroup>
        </div>
        <div className="col-4 text-center">
          <h3>council</h3>
          <div className="d-flex flex-row justify-content-between mx-3">
            <div className="d-flex flex-column">
              <div>1</div>
              <div>2</div>
              <div>3</div>
              <div>4</div>
              <div>5</div>
              <div>6</div>
            </div>
            <div className="d-flex flex-column">
              <div>7</div>
              <div>8</div>
              <div>9</div>
              <div>10</div>
              <div>11</div>
              <div>12</div>
            </div>
          </div>
          <h3>Proposals</h3>
          <div>200</div>
          <div>199</div>
          <div>198</div>
          <div>197</div>
          <div>196</div>
          <a href="/">more</a>
        </div>
        <div className="col-4 text-center">
          <h3>forum</h3>
          <div>post1</div>
          <div>post2</div>
          <div>post3</div>
          <div>post4</div>
          <div>post5</div>
        </div>
      </div>
      <div
        className="position-fixed w-100 p-3 text-light"
        style={{ bottom: '0px', height: '140px', background: '#000' }}
      >
        <small className="float-right p-2 text-right">
          734 resources
          <br />
          68 categories
          <br />
          20 channels
          <br />
          1231 hours
          <br />
          12389 GB
        </small>
        <div className="d-flex flex-row justify-content-between overflow-auto">
          {[10, `schism1`, 66, `schism2`, 15].map((i) => (
            <img
              key={i}
              src={`https://eu-central-1.linodeobjects.com/joystream/${i}.jpg`}
              width="200"
              alt={`${i}`}
            />
          ))}
        </div>
      </div>
    </div>
  )
}

export default Main
